@@ -38,9 +38,10 @@ class TestAnsiblePlaybookStart(Base):
     expected_link = ("http://infrastructure.fedoraproject.org/cgit/"
                      "ansible.git/tree/playbooks/groups/badges-backend.yml")
     expected_icon = "https://apps.fedoraproject.org/img/icons/ansible.png"
-    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
-                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set([])
     expected_usernames = set(['ralph'])
     expected_objects = set(['playbooks/groups/badges-backend.yml'])
@@ -73,9 +74,10 @@ class TestAnsiblePlaybookComplete(Base):
     expected_link = ("http://infrastructure.fedoraproject.org/cgit/"
                      "ansible.git/tree/playbooks/groups/badges-backend.yml")
     expected_icon = "https://apps.fedoraproject.org/img/icons/ansible.png"
-    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
-                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set([])
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -123,9 +125,10 @@ class TestAnsiblePlaybookCompleteNotCheckIn(Base):
     expected_subti = "ralph's badges-backend.yml playbook run completed"
     expected_link = None
     expected_icon = "https://apps.fedoraproject.org/img/icons/ansible.png"
-    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
-                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set([])
     expected_usernames = set(['ralph'])
     expected_objects = set([
